@@ -1,8 +1,8 @@
 package PubNub::PubSub;
 
 use strict;
-use warnings;
 use v5.10;
+our $VERSION = '1.1.0';
 
 use Carp;
 use Mojo::JSON qw/encode_json/;
@@ -11,15 +11,13 @@ use Mojo::Util qw/url_escape/;
 
 use PubNub::PubSub::Message;
 
-our $VERSION = '1.0.1';
-
-sub new {    ## no critic (RequireArgUnpacking)
+sub new {
     my $class = shift;
-    my %args = @_ % 2 ? %{$_[0]} : @_;
+    my %args  = @_ % 2 ? %{$_[0]} : @_;
 
-    $args{host}          ||= 'pubsub.pubnub.com';
-    $args{port}          ||= 80;
-    $args{timeout}       ||= 60;                    # for ua timeout
+    $args{host} ||= 'pubsub.pubnub.com';
+    $args{port} ||= 80;
+    $args{timeout} ||= 60; # for ua timeout
     $args{publish_queue} ||= [];
 
     my $proto = ($args{port} == 443) ? 'https://' : 'http://';
@@ -36,7 +34,7 @@ sub __ua {
     my $ua = Mojo::UserAgent->new;
     $ua->max_redirects(3);
     $ua->inactivity_timeout($self->{timeout});
-    $ua->proxy->detect;    # env proxy
+    $ua->proxy->detect; # env proxy
     $ua->cookie_jar(0);
     $ua->max_connections(100);
     $self->{ua} = $ua;
@@ -44,7 +42,7 @@ sub __ua {
     return $ua;
 }
 
-sub publish {              ## no critic (RequireArgUnpacking)
+sub publish {
     my $self = shift;
 
     my %params = @_ % 2 ? %{$_[0]} : @_;
@@ -53,20 +51,19 @@ sub publish {              ## no critic (RequireArgUnpacking)
     my $ua = $self->__ua;
 
     my @steps = map {
-        my $ref = $_;
-        my $url = $ref->{url};
-        sub {
-            my $delay = shift;
-            my $end   = $delay->begin;
-            $ua->get(
-                $url => sub {
+             my $ref = $_;
+             my $url = $ref->{url};
+             sub {
+                 my $delay = shift;
+                 my $end = $delay->begin;
+                 $ua->get($url => sub {
                     $callback->($_[1]->res, $ref->{message}) if $callback;
                     $end->();
-                });
-            }
+                  });
+             }
     } $self->__construct_publish_urls(%params);
 
-    return Mojo::IOLoop->delay(@steps)->wait;
+    Mojo::IOLoop->delay(@steps)->wait;
 }
 
 sub __construct_publish_urls {
@@ -82,18 +79,13 @@ sub __construct_publish_urls {
 
     return map {
         my $json = $_->json;
-        my $uri  = Mojo::URL->new($self->{web_host} . qq~/publish/$pub_key/$sub_key/0/$channel/0/~ . url_escape($json));
+        my $uri = Mojo::URL->new( $self->{web_host} . qq~/publish/$pub_key/$sub_key/0/$channel/0/~ . url_escape($json) );
         $uri->query($_->query_params(\%params));
-        {
-            url     => $uri->to_string,
-            message => $_
-        };
-        } map {
-        PubNub::PubSub::Message->new($_)
-        } @{$params{messages}};
+        { url => $uri->to_string, message => $_ };
+    } map { PubNub::PubSub::Message->new($_) } @{$params{messages}};
 }
 
-sub subscribe {    ## no critic (RequireArgUnpacking)
+sub subscribe {
     my $self = shift;
     my %params = @_ % 2 ? %{$_[0]} : @_;
 
@@ -111,7 +103,7 @@ sub subscribe {    ## no critic (RequireArgUnpacking)
     unless ($tx->success) {
         # for example $tx->error->{message} =~ /Inactivity timeout/
 
-        # This is not a traditional goto. Instead it exits this function
+        # This is not a traditional goto. Instead it exits this function 
         # and re-enters with @ as params.
         #
         # see goto docs, this is basically a method call which exits the current
@@ -121,7 +113,7 @@ sub subscribe {    ## no critic (RequireArgUnpacking)
         goto &subscribe;
     }
     my $json = $tx->res->json;
-    my @cb_args = $params{raw_msg} ? ($json) : (@{$json->[0]});
+    my @cb_args = $params{raw_msg}? ($json) : (@{$json->[0]});
 
     my $rtn = $callback ? $callback->(@cb_args) : 1;
     return unless $rtn;
@@ -130,55 +122,53 @@ sub subscribe {    ## no critic (RequireArgUnpacking)
     return $self->subscribe(%params, timetoken => $timetoken);
 }
 
-sub subscribe_multi {    ## no critic (RequireArgUnpacking)
+sub subscribe_multi {
     my $self = shift;
     my %params = @_ % 2 ? %{$_[0]} : @_;
     croak 'channels must be an arrayref'
-        unless ref($params{channels}) =~ /ARRAY/;
+         unless ref($params{channels}) =~ /ARRAY/;
     croak 'callback must be a hashref or coderef'
-        unless ref($params{callback}) =~ /(HASH|CODE)/;
+         unless ref($params{callback}) =~ /(HASH|CODE)/;
 
     my $callback;
-    if (ref($params{callback}) =~ /HASH/) {
-        for (keys %{$params{callback}}) {
-            croak "Non-coderef value found for callback key $_"
+    if (ref($params{callback}) =~ /HASH/){
+       for (keys %{$params{callback}}) {
+           croak "Non-coderef value found for callback key $_" 
                 unless ref($params{callback}->{$_}) =~ /CODE/;
-        }
-        $callback = sub {
-            my ($obj) = @_;
-            my (undef, undef, $channel) = @$obj;
-            my $cb_dispatch = $params{callback};
-            unless ($channel) {    # on connect messages
-                goto $cb_dispatch->{on_connect}
-                    if exists $cb_dispatch->{on_connect};
-                return 1;
-            }
-            if (exists $cb_dispatch->{$channel}) {
+       }
+       $callback = sub {
+           my ($obj) = @_;
+           my ($msg, $timetoken, $channel) = @$obj;
+           my $cb_dispatch = $params{callback};
+           unless ($channel) { # on connect messages
+              goto $cb_dispatch->{on_connect} 
+                   if exists $cb_dispatch->{on_connect};
+              return 1;
+           }
+           if (exists $cb_dispatch->{$channel}){
 
-                # these are verified coderefs, so replacing the current stack
-                # frame with a call to the function.  They will *not* jump to
-                # a label or other points.  Basically this just lets us pretend
-                # that this was called directly by subscribe above.
-                goto $cb_dispatch->{$channel};
-            } elsif (exists $cb_dispatch->{'_default'}) {
-                goto $cb_dispatch->{_default};
-            } else {
-                warn 'Using callback dispatch table, cannot find channel callback' . ' and _default callback not specified';
-                return;
-            }
-        };
+              # these are verified coderefs, so replacing the current stack 
+              # frame with a call to the function.  They will *not* jump to 
+              # a label or other points.  Basically this just lets us pretend
+              # that this was called directly by subscribe above.
+              goto $cb_dispatch->{$channel};
+           } elsif (exists $cb_dispatch->{'_default'}){
+              goto $cb_dispatch->{_default};
+           } else {
+              warn 'Using callback dispatch table, cannot find channel callback'
+                   . ' and _default callback not specified';
+              return;
+           }
+       };
     }
     $callback = $params{callback} unless ref $callback;
 
     my $channel_string = join ',', @{$params{channels}};
-    return $self->subscribe(
-        channel  => $channel_string,
-        callback => $callback,
-        raw_msg  => 1
-    );
+    return $self->subscribe(channel => $channel_string, callback => $callback,
+                           raw_msg => 1);
 }
 
-sub history {    ## no critic (RequireArgUnpacking)
+sub history {
     my $self = shift;
 
     if (scalar(@_) == 1 and ref($_[0]) ne 'HASH' and $_[0] =~ /^\d+$/) {
@@ -354,10 +344,10 @@ an arrayref of channel names
 A callback, either a coderef which handles all requests, or a hashref dispatch
 table with one entry per channel.
 
-If a dispatch table is used a _default entry catches all unrecognized channels.
+If a dispatch table is used a _default entry catches all unrecognized channels. 
 If an unrecognized channel is found, a warning is generated and the loop exits.
 
-The message results are passed into the functions in raw_msg form (i.e. a tuple
+The message results are passed into the functions in raw_msg form (i.e. a tuple 
 ref of (\@messages, $timetoken, $channel) for performance reasons.
 
 =back
@@ -499,8 +489,8 @@ for example, to fetch all the rows in history
 
 This module effectively runs a Mojolicious application in the background.  For
 those parts of JSON which do not have a hard Perl equivalent, such as booleans,
-the Mojo::JSON module's semantics work.  This means that JSON bools are
-handled as references to scalar values 0 and 1 (i.e. \0 for false and \1 for
+the Mojo::JSON module's semantics work.  This means that JSON bools are 
+handled as references to scalar values 0 and 1 (i.e. \0 for false and \1 for 
 true).
 
 This has changed since 0.08, where True and False were used.
@@ -513,4 +503,44 @@ L<https://github.com/binary-com/perl-pubnub-pubsub>
 
 Binary.com E<lt>fayland@gmail.comE<gt>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2014- binary.com.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 =cut
